@@ -9,6 +9,9 @@
 #'`1` is the darkest vignetting, while `0` is no vignetting. If vignette is a length-2 vector, the second entry will
 #'control the blurriness of the vignette effect (`1` is the default, e.g. `2` would double the blurriness but would take
 #'much longer to compute).
+#'@param radius Default `1.3`. Multiplier for the size of the vignette. If `1`, the vignette touches
+#'the edge of the image.
+#'@param color Default `"#000000"` (black). Color of the vignette.
 #'@param preview Default `FALSE`. If `TRUE`, it will display the image in addition
 #'to returning it.
 
@@ -16,7 +19,7 @@
 #'@import grDevices
 #'@export
 #'@examples
-#'if(interactive()){
+#'#if(interactive()){
 #'#Plot the dragon
 #'plot_image(dragon)
 #'
@@ -29,12 +32,23 @@
 #'add_vignette(dragon, preview = TRUE, vignette = 1)
 #'}
 #'
+#'#Change the radius:
+#'\donttest{
+#'add_vignette(dragon, preview = TRUE, vignette = 1, radius=1.5)
+#'add_vignette(dragon, preview = TRUE, vignette = 1, radius=0.5)
+#'}
+#'
+#'#Change the color:
+#'\donttest{
+#'add_vignette(dragon, preview = TRUE, vignette = 1, color="white")
+#'}
 #'#Increase the width of the blur by 50%:
 #'\donttest{
 #'add_vignette(dragon, preview = TRUE, vignette = c(1,1.5))
 #'}
-#'}
-add_vignette = function(image, vignette = 0.5, filename = NULL, preview = FALSE) {
+#'#end}
+add_vignette = function(image, vignette = 0.5, color = "#000000", radius = 1.3,
+                        filename = NULL, preview = FALSE) {
   imagetype = get_file_type(image)
   temp = tempfile(fileext = ".png")
   if(imagetype == "array") {
@@ -80,7 +94,8 @@ add_vignette = function(image, vignette = 0.5, filename = NULL, preview = FALSE)
   } else {
     vignette = 0.4
   }
-  imagefile = make_vignette_overlay(dimensions[1],dimensions[2], vignette, radiusval)
+  imagefile = make_vignette_overlay(width=dimensions[1],height=dimensions[2],
+                                    intensity=vignette, radius=radiusval, radius_multiplier = radius, color=color)
   magick::image_read(temp) %>%
     magick::image_composite(magick::image_read(imagefile)) %>%
     magick::image_write(path = temp, format = "png")
