@@ -10,9 +10,9 @@
 #'@import stats
 #'@export
 #'@examples
-#'if(interactive()){
+#'#if(interactive()){
 #'image(generate_2d_gaussian(1,1,31), asp=1)
-#'}
+#'#end}
 generate_2d_gaussian = function(sd = 1, power = 1, dim = c(11,11), width = 3) {
   if(length(dim) == 1) {
     dim = c(dim, dim)
@@ -26,14 +26,18 @@ generate_2d_gaussian = function(sd = 1, power = 1, dim = c(11,11), width = 3) {
     x = seq(-width,width,length.out = dim[1])
     y = seq(-width/xy_ratio,width/xy_ratio,length.out = dim[2])
   }
-  testmat = matrix(0,dim[1],dim[2])
+  testmat = matrix(0,length(x),length(y))
   if(sd == 0) {
     sd == 0.00001
   }
-  for(i in 1:length(x)) {
-    for(j in 1:length(y)) {
-      testmat[i,j] = (dnorm(power*x[i],mean=0,sd=sd) * dnorm(power*y[j],mean=0,sd=sd))
+  if(length(x) > 0 && length(y) > 0) {
+    for(i in 1:length(x)) {
+      for(j in 1:length(y)) {
+        testmat[i,j] = (dnorm(power*x[i],mean=0,sd=sd) * dnorm(power*y[j],mean=0,sd=sd))
+      }
     }
+  } else {
+    stop("Kernel dimension too small")
   }
   testmat/sum(testmat)
 }
